# tiempo
Twisted Task Scheduling for Django


## Dev Setup

```bash
virtualenv tiempo --no-site-packages --distributed
source tiempo/bin/activate
pip install -e <path to your tiempo repo>
```

Then to test this shit out just run:

```bash
./tiempo/scripts/metronome
```
